@@ -1,4 +1,4 @@
-import importlib
+import importlib.util
 
 if importlib.util.find_spec("smolagents") is not None:
     from .smolagents import SmolAgentsAdapter
@@ -8,3 +8,6 @@ if importlib.util.find_spec("llamaindex") is not None:
 
 if importlib.util.find_spec("chainlit") is not None:
     from .chainlit import ChainlitAdapter, ChainlitXpanderDataLayer
+
+if importlib.util.find_spec("agno") is not None:
+    from .agno import AgnoAdapter, AgnoStorage
