@@ -17,7 +17,7 @@ class SDKAdapter:
 
     agent: Agent
 
-    def __init__(self, api_key: str, agent_id: str, base_url: Optional[str] = None, organization_id: Optional[str] = None, should_reset_cache: Optional[bool] = False, with_metrics_report: Optional[bool] = False):
+    def __init__(self, api_key: str, agent_id: str, base_url: Optional[str] = None, organization_id: Optional[str] = None, should_reset_cache: Optional[bool] = False, with_metrics_report: Optional[bool] = False, version: Optional[int] = None):
         """
         Initialize the SDKAdapter with the provided API key and agent ID.
 
@@ -29,7 +29,7 @@ class SDKAdapter:
             with_metrics_report (Optional[bool], optional): If to auto-report metrics (llm & execution). Default to False
         """
         self.xpander_client = XpanderClient(api_key=api_key, base_url=base_url, organization_id=organization_id,should_reset_cache=should_reset_cache)
-        self.agent = self.xpander_client.agents.get(agent_id=agent_id)
+        self.agent = self.xpander_client.agents.get(agent_id=agent_id, version=version)
         self.with_metrics_report = with_metrics_report
         self.execution_tokens: Dict[str, Tokens] = {}
 
@@ -40,10 +40,12 @@ class SDKAdapter:
         Returns:
             str: The formatted system prompt.
         """
+        agent_role = "\n".join(self.agent.instructions.role)
+        agent_goal = "\n".join(self.agent.instructions.goal)
         return f"""
             Agent general instructions: "{self.agent.instructions.general}"\n
-            Agent role instructions: "{self.agent.instructions.role}"\n
-            Agent goal instructions: "{self.agent.instructions.goal}"
+            Agent role instructions: "{agent_role}"\n
+            Agent goal instructions: "{agent_goal}"
         """
 
     def get_tools(self) -> List[Any]:
