@@ -230,7 +230,7 @@ class ChainlitXpanderDataLayer(BaseDataLayer):
             organization_id=organization_id,
         )
         threads = Memory.fetch_user_threads(
-            agent={"configuration": xpander.configuration, "userDetails": {"id": filters.userId}}
+            agent={"id": agent_id, "configuration": xpander.configuration, "userDetails": {"id": filters.userId}}
         )
         
         # filter to current agent only.
@@ -362,7 +362,8 @@ class ChainlitAdapter(SDKAdapter):
         user: Optional[User] = None,
         with_agent_end_tool: Optional[bool] = False,
         should_reset_cache: Optional[bool] = False,
-        with_metrics_report: Optional[bool] = False
+        with_metrics_report: Optional[bool] = False,
+        version: Optional[int] = None
     ):
         """
         Initialize the ChainlitAdapter.
@@ -374,7 +375,15 @@ class ChainlitAdapter(SDKAdapter):
             organization_id (Optional[str], optional): The organization ID, if applicable. Defaults to None.
             with_metrics_report (Optional[bool], optional): If to auto-report metrics (llm & execution). Default to False.
         """
-        super().__init__(api_key=api_key, agent_id=agent_id, base_url=base_url, organization_id=organization_id, should_reset_cache=should_reset_cache, with_metrics_report=with_metrics_report)
+        super().__init__(
+            api_key=api_key,
+            agent_id=agent_id,
+            base_url=base_url,
+            organization_id=organization_id,
+            should_reset_cache=should_reset_cache,
+            with_metrics_report=with_metrics_report,
+            version=version
+        )
         
         if not with_agent_end_tool:
             self.agent.disable_agent_end_tool()  # No need since SmolAgents handles it.
@@ -527,20 +536,24 @@ class ChainlitAdapter(SDKAdapter):
 
     def get_custom_graph_items(self, tool_name: str) -> GraphItem:
         random_uuid = get_uuid()
-        if tool_name == "xpstorage-save":
+        if tool_name == "xpsleep-agent-delay":
+            return GraphItem(agent=self.agent, id=random_uuid, item_id=random_uuid, name="Sleep", type=AgentGraphItemType.TOOL)
+        elif tool_name == "xpstorage-save":
             return GraphItem(agent=self.agent, id=random_uuid, item_id=random_uuid, name="Save Item to Storage", type=AgentGraphItemType.TOOL)
         elif tool_name == "xpstorage-search":
             return GraphItem(agent=self.agent, id=random_uuid, item_id=random_uuid, name="Search Items in Storage", type=AgentGraphItemType.TOOL)
         elif tool_name == "xpstorage-get-last-item":
             return GraphItem(agent=self.agent, id=random_uuid, item_id=random_uuid, name="Retrieve Latest Item from Storage", type=AgentGraphItemType.TOOL)
-        elif tool_name.startswith("xpkb"):
+        elif tool_name.startswith("xpkbs"):
             return GraphItem(agent=self.agent, id=random_uuid, item_id=random_uuid, name="Search Knowledge Base", type=AgentGraphItemType.TOOL)
+        elif tool_name.startswith("xpkba"):
+            return GraphItem(agent=self.agent, id=random_uuid, item_id=random_uuid, name="Adding items to Knowledge Base", type=AgentGraphItemType.TOOL)
         elif tool_name.startswith("xpcoder"):
             return GraphItem(agent=self.agent, id=random_uuid, item_id=random_uuid, name="Running Coding Agent", type=AgentGraphItemType.TOOL)
         return
 
     
-    async def process_tool_calls(self,run_id: str, tool_calls: Dict[int, ChainlitToolCallWithLLMResponse], is_sequence_agent: bool = False, sequence_agent_graph_items:List[GraphItem] = [], reported_sequence_sub_agent_ids: set = set(), on_node_enter: Optional[Callable] = None, on_node_error: Optional[Callable] = None, check_if_agent_has_dedicated_workers: Optional[Callable] = None, get_agent_emoji: Optional[Callable] = None, agent_custom_functions: list[GraphItem] = [], local_tools: Dict[str, Callable] = None) -> str | None:
+    async def process_tool_calls(self,run_id: str, tool_calls: Dict[int, ChainlitToolCallWithLLMResponse], is_sequence_agent: bool = False, sequence_agent_graph_items:List[GraphItem] = [], reported_sequence_sub_agent_ids: set = set(), on_node_enter: Optional[Callable] = None, on_node_error: Optional[Callable] = None, has_dedicated_workers: Optional[bool] = None, agent_emoji: Optional[str] = None, agent_custom_functions: list[GraphItem] = [], local_tools: Dict[str, Callable] = None) -> str | None:
         """
         Process tool calls by formatting their payloads and executing them.
 
@@ -605,10 +618,8 @@ class ChainlitAdapter(SDKAdapter):
             await wait(seconds=1)
             
             agent_name = self.agent.name
-            if get_agent_emoji:
-                emoji = get_agent_emoji(agent_id=self.agent.id)
-                if emoji:
-                    agent_name = f"{emoji} {agent_name}"
+            if agent_emoji:
+                agent_name = f"{agent_emoji} {agent_name}"
                 
             seq_sub_item= cl.Step(
                 type="tool",
@@ -654,10 +665,8 @@ class ChainlitAdapter(SDKAdapter):
                         await on_node_enter(tool_call=tool_call,graph_item=sub_agent_node)
                     tool_name = sub_agent_node.name
                     
-                    if get_agent_emoji:
-                        emoji = get_agent_emoji(agent_id=sub_agent_node.item_id)
-                        if emoji:
-                            tool_name = f"{emoji} {tool_name}"
+                    if agent_emoji:
+                        tool_name = f"{agent_emoji} {tool_name}"
                     
                     current_step.id = run_id+"_"+sub_agent_node.item_id
                     is_sub_agent_root = True
@@ -671,10 +680,8 @@ class ChainlitAdapter(SDKAdapter):
                 if is_agent_end_tool:
                     current_step.default_open = True
                     agent_name = self.agent.name
-                    if get_agent_emoji:
-                        emoji = get_agent_emoji(agent_id=self.agent.id)
-                        if emoji:
-                            agent_name = f"{emoji} {agent_name}"
+                    if agent_emoji:
+                        agent_name = f"{agent_emoji} {agent_name}"
                             
                     tool_name = f"{agent_name} - Final Thoughts"
                     should_send_step = False
@@ -687,8 +694,12 @@ class ChainlitAdapter(SDKAdapter):
             if is_debug_mode_active:
                 current_step.name = tool_name
                 if is_sub_agent_execution:
-                    input_task_str = tool_call.payload['bodyParams'].get("input_task", "")
-                    if not input_task_str:
+                    input_task_str = ""
+                    try:
+                        input_task_str = tool_call.payload['bodyParams'].get("input_task", "")
+                        if not input_task_str:
+                            input_task_str = json.dumps(tool_call.payload)
+                    except Exception:
                         input_task_str = json.dumps(tool_call.payload)
                     current_step.input = input_task_str
                 else:
@@ -762,10 +773,8 @@ class ChainlitAdapter(SDKAdapter):
                     tool_call_result = await make_async(self.agent.run_tool)(tool=tool_call, payload_extension={"headers":{"x-xpander-source-node-type": SourceNodeType.ASSISTANT.value.lower()}})
                     
                     # check if has dedicated worker and wait for result. let the user refresh the result
-                    if graph_item and graph_item.type.value == AgentGraphItemType.AGENT.value and check_if_agent_has_dedicated_workers:
-                        has_dedicated_workers = await check_if_agent_has_dedicated_workers(agent_id=graph_item.item_id,organization_id=self.agent.organization_id)
-                        if has_dedicated_workers:
-                            return "waiting_for_sub_agent_result"
+                    if graph_item and graph_item.type.value == AgentGraphItemType.AGENT.value and has_dedicated_workers:
+                        return "waiting_for_sub_agent_result"
                     
             
             current_step.end = utc_now()
